#!/bin/bash

## Script to convert the PDF form data of PDF forms made by newer versions of Adobe Acrobat
## into gerneral form data according to standard.
## The script is usefull if one uses e.g. the program okular of KDE/Plasma to fill in PDF forms
## where the filled text is not seen anymore after switching to the pure display mode.

## v1 23-12-21 alban: script base
## v2 23-12-23 alban: add help text and error message
## v3 24-01-15 alban: add acceptance for wildcard *
## v4 24-01-17 alban: add file type check
## v5 24-01-23 alban: add binary check
## v6 24-02-08 alban: add direct help option call


##
helptext () {
    echo "\
    \n\
    This bash script rewrites the already filled in text of PDF forms \n\
    to keep text visible in some viewer's (e.g. okular from KDE) display mode: \n\
       ${0##*/} PDF_1 [... PDF_n] \n\
    or prints this help text again: \n\
       ${0##*/} --help | -h \n\
    \n\
    Use with one or more files (spaces in file name need quoting or escaping): \n\
       ${0##*/} Example_1.pdf \"Example 2.pdf\" Example\ 3.pdf \n\
    \n\
    Can be used also with wildcard: \n\
       ${0##*/} More_Examples_*.pdf \n\
    \n\
    "   
}

## check for needed binaries
## give needed binaries as space-seperated entries in variable $progs2check
##
progs2check="pdftk"
##
for prog in $progs2check; do
	if ! which "$prog" > /dev/null; then
		echo "\n   ERROR: Couldn't find the program $prog. \n"
		exit 1
  	fi
done

## help request as parameter
case "$1" in
	-h|--help) 	helptext
			exit 0
	;;
esac

## no parameter
if [ -z "$1" ]; then
    echo "\n \n   ERROR: No file given. \n"
    helptext
    exit 0
fi

## set internal field separator (IFS) because of possible spaces in file names
IFS="
"
for param in $*; do
    echo "\n   Processing: $param"
## check for file type    
    if [ $(file --mime-type -b "$param") != application/pdf ];
        then echo "   WARNING: $param seems to be not a PDF file. \n"
        continue
    fi
## get file name without extension
    filename="${param%.*}"
    newfilename="${filename}"_corr-$(date +%y-%m-%d-%H%M%S).pdf
## extract form content to FDF, then fill in form in a file copy by FDF content, then clean up    
    pdftk "${param}" generate_fdf output "${filename}".fdf
    pdftk "${param}" fill_form "${filename}".fdf output "${newfilename}"
    rm "${filename}".fdf
    echo "   Result:     ${newfilename}"
done

